@@ -1,10 +1,12 @@
 import re
 
 from .common import InfoExtractor
+from .senategov import SenateISVPIE
+from .ustream import UstreamIE
 from ..compat import compat_HTMLParseError
 from ..utils import (
-    determine_ext,
     ExtractorError,
+    determine_ext,
     extract_attributes,
     find_xpath_attr,
     get_element_by_attribute,
@@ -19,8 +21,6 @@ from ..utils import (
     str_to_int,
     unescapeHTML,
 )
-from .senategov import SenateISVPIE
-from .ustream import UstreamIE
 
 
 class CSpanIE(InfoExtractor):
@@ -43,7 +43,7 @@ class CSpanIE(InfoExtractor):
             'ext': 'mp4',
             'title': 'CSPAN - International Health Care Models',
             'description': 'md5:7a985a2d595dba00af3d9c9f0783c967',
-        }
+        },
     }, {
         'url': 'http://www.c-span.org/video/?318608-1/gm-ignition-switch-recall',
         'info_dict': {
@@ -61,7 +61,7 @@ class CSpanIE(InfoExtractor):
         },
         'params': {
             'skip_download': True,  # m3u8 downloads
-        }
+        },
     }, {
         # Ustream embedded video
         'url': 'https://www.c-span.org/video/?114917-1/armed-services',
@@ -151,7 +151,7 @@ class CSpanIE(InfoExtractor):
 
         # Obsolete
         # We first look for clipid, because clipprog always appears before
-        patterns = [r'id=\'clip(%s)\'\s*value=\'([0-9]+)\'' % t for t in ('id', 'prog')]
+        patterns = [rf'id=\'clip({t})\'\s*value=\'([0-9]+)\'' for t in ('id', 'prog')]
         results = list(filter(None, (re.search(p, webpage) for p in patterns)))
         if results:
             matches = results[0]
@@ -183,13 +183,13 @@ class CSpanIE(InfoExtractor):
             return d.get(attr, {}).get('#text')
 
         data = self._download_json(
-            'http://www.c-span.org/assets/player/ajax-player.php?os=android&html5=%s&id=%s' % (video_type, video_id),
+            f'http://www.c-span.org/assets/player/ajax-player.php?os=android&html5={video_type}&id={video_id}',
             video_id)['video']
         if data['@status'] != 'Success':
-            raise ExtractorError('%s said: %s' % (self.IE_NAME, get_text_attr(data, 'error')), expected=True)
+            raise ExtractorError('{} said: {}'.format(self.IE_NAME, get_text_attr(data, 'error')), expected=True)
 
         doc = self._download_xml(
-            'http://www.c-span.org/common/services/flashXml.php?%sid=%s' % (video_type, video_id),
+            f'http://www.c-span.org/common/services/flashXml.php?{video_type}id={video_id}',
             video_id)
 
         description = self._html_search_meta('description', webpage)
@@ -205,7 +205,7 @@ class CSpanIE(InfoExtractor):
             formats = []
             for quality in f.get('qualities', []):
                 formats.append({
-                    'format_id': '%s-%sp' % (get_text_attr(quality, 'bitrate'), get_text_attr(quality, 'height')),
+                    'format_id': '{}-{}p'.format(get_text_attr(quality, 'bitrate'), get_text_attr(quality, 'height')),
                     'url': unescapeHTML(get_text_attr(quality, 'file')),
                     'height': int_or_none(get_text_attr(quality, 'height')),
                     'tbr': int_or_none(get_text_attr(quality, 'bitrate')),
@@ -216,13 +216,13 @@ class CSpanIE(InfoExtractor):
                     continue
                 formats = self._extract_m3u8_formats(
                     path, video_id, 'mp4', entry_protocol='m3u8_native',
-                    m3u8_id='hls') if determine_ext(path) == 'm3u8' else [{'url': path, }]
+                    m3u8_id='hls') if determine_ext(path) == 'm3u8' else [{'url': path}]
             add_referer(formats)
             entries.append({
-                'id': '%s_%d' % (video_id, partnum + 1),
+                'id': f'{video_id}_{partnum + 1}',
                 'title': (
                     title if len(files) == 1 else
-                    '%s part %d' % (title, partnum + 1)),
+                    f'{title} part {partnum + 1}'),
                 'formats': formats,
                 'description': description,
                 'thumbnail': thumbnail,
@@ -230,7 +230,7 @@ class CSpanIE(InfoExtractor):
                 'subtitles': {
                     'en': [{
                         'url': capfile,
-                        'ext': determine_ext(capfile, 'dfxp')
+                        'ext': determine_ext(capfile, 'dfxp'),
                     }],
                 } if capfile else None,
             })
@@ -257,8 +257,8 @@ class CSpanCongressIE(InfoExtractor):
             'title': 'Congressional Chronicle - Members of Congress, Hearings and More',
             'description': 'md5:54c264b7a8f219937987610243305a84',
             'thumbnail': r're:https://ximage.c-spanvideo.org/.+',
-            'ext': 'mp4'
-        }
+            'ext': 'mp4',
+        },
     }]
 
     def _real_extract(self, url):
