@@ -22,7 +22,7 @@ class DFBIE(InfoExtractor):
         display_id, video_id = self._match_valid_url(url).groups()
 
         player_info = self._download_xml(
-            'http://tv.dfb.de/server/hd_video.php?play=%s' % video_id,
+            f'http://tv.dfb.de/server/hd_video.php?play={video_id}',
             display_id)
         video_info = player_info.find('video')
         stream_access_url = self._proto_relative_url(video_info.find('url').text.strip())
@@ -46,7 +46,7 @@ class DFBIE(InfoExtractor):
             'id': video_id,
             'display_id': display_id,
             'title': video_info.find('title').text,
-            'thumbnail': 'http://tv.dfb.de/images/%s_640x360.jpg' % video_id,
+            'thumbnail': f'http://tv.dfb.de/images/{video_id}_640x360.jpg',
             'upload_date': unified_strdate(video_info.find('time_date').text),
             'formats': formats,
         }
