@@ -1,9 +1,5 @@
 from .common import InfoExtractor
-from ..utils import (
-    int_or_none,
-    parse_duration,
-    parse_iso8601
-)
+from ..utils import int_or_none, parse_duration, parse_iso8601
 
 
 class PornFlipIE(InfoExtractor):
@@ -47,7 +43,7 @@ class PornFlipIE(InfoExtractor):
     def _real_extract(self, url):
         video_id = self._match_id(url)
         webpage = self._download_webpage(
-            'https://{}/sv/{}'.format(self._HOST, video_id), video_id, headers={'host': self._HOST})
+            f'https://{self._HOST}/sv/{video_id}', video_id, headers={'host': self._HOST})
         description = self._html_search_regex(r'&p\[summary\]=(.*?)\s*&p', webpage, 'description', fatal=False)
         duration = self._search_regex(r'"duration":\s+"([^"]+)",', webpage, 'duration', fatal=False)
         view_count = self._search_regex(r'"interactionCount":\s+"([^"]+)"', webpage, 'view_count', fatal=False)
